@@ -10,7 +10,7 @@ import pandas
 
 
 @pandas.api.extensions.register_dataframe_accessor("powerplant")
-class PowerPlantAccessor():
+class PowerPlantAccessor:
     """
     Accessor object for DataFrames created with powerplantmatching.
     This simplifies the access to common functions applicable to dataframes
@@ -31,21 +31,34 @@ class PowerPlantAccessor():
     def __init__(self, pandas_obj):
         self._obj = pandas_obj
 
-    from .plot import powerplant_map as plot_map
-    from .utils import (lookup, set_uncommon_fueltypes_to_other,
-                        select_by_projectID, breakdown_matches,
-                        fill_geoposition, convert_country_to_alpha2,
-                        convert_alpha2_to_country)
-    from .export import to_pypsa_names, map_bus, map_country_bus
+    from .cleaning import aggregate_units, clean_powerplantname
+    from .export import map_bus, map_country_bus, to_pypsa_names
     from .heuristics import (
-        extend_by_non_matched, scale_to_net_capacities,
-        fill_missing_commyears, extend_by_VRE, fill_missing_duration,
-        rescale_capacities_to_country_totals, fill_missing_decommyears)
-    from .cleaning import clean_powerplantname, aggregate_units
+        extend_by_non_matched,
+        extend_by_VRE,
+        fill_missing_commissioning_years,
+        fill_missing_commyears,
+        fill_missing_decommissioning_years,
+        fill_missing_decommyears,
+        fill_missing_duration,
+        isin,
+        rescale_capacities_to_country_totals,
+        scale_to_net_capacities,
+    )
     from .matching import reduce_matched_dataframe
+    from .plot import powerplant_map as plot_map
+    from .utils import (
+        breakdown_matches,
+        convert_alpha2_to_country,
+        convert_country_to_alpha2,
+        convert_to_short_name,
+        fill_geoposition,
+        lookup,
+        select_by_projectID,
+        set_uncommon_fueltypes_to_other,
+    )
 
-    def plot_aggregated(self, by=['Country', 'Fueltype'], figsize=(12, 20),
-                        **kwargs):
+    def plot_aggregated(self, by=["Country", "Fueltype"], figsize=(12, 20), **kwargs):
         """
         Plotting function for fast inspection of the capacity distribution.
         Returns figure and axes of a matplotlib barplot.
@@ -62,13 +75,15 @@ class PowerPlantAccessor():
 
         """
         import matplotlib.pyplot as plt
-        from .utils import lookup, convert_country_to_alpha2
+
+        from .utils import convert_country_to_alpha2, lookup
+
         subplots = True if len(by) > 1 else False
         fig, ax = plt.subplots(figsize=figsize, **kwargs)
         df = lookup(convert_country_to_alpha2(self._obj), by=by)
         df = df.unstack().rename_axis(None) if subplots else df
         df.plot.bar(subplots=subplots, sharex=False, ax=ax)
-        fig.tight_layout(h_pad=1.)
+        fig.tight_layout(h_pad=1.0)
         return fig, ax
 
     def set_name(self, name):
@@ -77,17 +92,14 @@ class PowerPlantAccessor():
     def get_name(self):
         return self._obj.columns.name
 
-    def match_with(self, df, labels=None, use_saved_matches=False,
-                   config=None, reduced=True, **dukeargs):
-        from .matching import (combine_multiple_datasets,
-                               reduce_matched_dataframe)
+    def match_with(self, df, labels=None, config=None, reduced=True, **dukeargs):
+        from .matching import combine_multiple_datasets, reduce_matched_dataframe
         from .utils import to_list_if_other
 
         dfs = [self._obj] + to_list_if_other(df)
-        res = combine_multiple_datasets(
-            dfs, labels, use_saved_matches=use_saved_matches, config=config,
-            **dukeargs)
+        res = combine_multiple_datasets(dfs, labels, config=config, **dukeargs)
         if reduced:
             return res.pipe(reduce_matched_dataframe, config=config)
         return res
+
     pass
